@@ -310,7 +310,7 @@ class API(LoggerMixin, object):
         return self._get_series_data(categories_dict.keys())
 
     def data_by_series(self,
-                       series: str):
+                       series: Union[str, List]):
         """API EIASeries Query
 
         Args:
@@ -319,4 +319,7 @@ class API(LoggerMixin, object):
         Returns:
 
         """
-        return self._get_series_data((series,))
+        if isinstance(series, str):
+            return self._get_series_data((series,))
+        else:
+            return self._get_series_data(series)
